@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2020 by the Free Software Foundation, Inc.
+# Copyright (C) 2015-2021 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -108,11 +108,11 @@ class TestCLIMembers(unittest.TestCase):
             result = self._command.invoke(members, (
                 '--add', infp.name, 'ant.example.com'))
         self.assertEqual(
-           result.output,
-           'Warning: The --add option is deprecated. Use '
-           '`mailman addmembers` instead.\n'
-           'Already subscribed (skipping): Anne Person <aperson@example.com>\n'
-           )
+            result.output,
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --add option is removed. Use '
+            '`mailman addmembers` instead.\n')
 
     def test_add_invalid_email(self):
         with NamedTemporaryFile('w', buffering=1, encoding='utf-8') as infp:
@@ -120,11 +120,11 @@ class TestCLIMembers(unittest.TestCase):
             result = self._command.invoke(members, (
                 '--add', infp.name, 'ant.example.com'))
         self.assertEqual(
-           result.output,
-           'Warning: The --add option is deprecated. Use '
-           '`mailman addmembers` instead.\n'
-           'Cannot parse as valid email address (skipping): foobar@\n'
-           )
+            result.output,
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --add option is removed. Use '
+            '`mailman addmembers` instead.\n')
 
     def test_not_subscribed_without_display_name(self):
         with NamedTemporaryFile('w', buffering=1, encoding='utf-8') as infp:
@@ -132,12 +132,11 @@ class TestCLIMembers(unittest.TestCase):
             result = self._command.invoke(members, (
                 '--delete', infp.name, 'ant.example.com'))
         self.assertEqual(
-           result.output,
-           'Warning: The --delete option is deprecated. Use '
-           '`mailman delmembers` instead.\n'
-           'Member not subscribed (skipping): '
-           'aperson@example.com\n'
-           )
+            result.output,
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --delete option is removed. Use '
+            '`mailman delmembers` instead.\n')
 
     def test_not_subscribed_with_display_name(self):
         with NamedTemporaryFile('w', buffering=1, encoding='utf-8') as infp:
@@ -145,12 +144,11 @@ class TestCLIMembers(unittest.TestCase):
             result = self._command.invoke(members, (
                 '--delete', infp.name, 'ant.example.com'))
         self.assertEqual(
-           result.output,
-           'Warning: The --delete option is deprecated. Use '
-           '`mailman delmembers` instead.\n'
-           'Member not subscribed (skipping): '
-           'Anne Person <aperson@example.com>\n'
-           )
+            result.output,
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --delete option is removed. Use '
+            '`mailman delmembers` instead.\n')
 
     def test_deletion_blank_lines(self):
         subscribe(self._mlist, 'Anne')
@@ -166,15 +164,17 @@ class TestCLIMembers(unittest.TestCase):
                 '--delete', infp.name, 'ant.example.com'))
         self.assertEqual(
             result.output,
-            'Warning: The --delete option is deprecated. Use '
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --delete option is removed. Use '
             '`mailman delmembers` instead.\n')
         with NamedTemporaryFile('w', encoding='utf-8') as outfp:
             self._command.invoke(members, (
                 '-o', outfp.name, 'ant.example.com'))
             with open(outfp.name, 'r', encoding='utf-8') as infp:
                 lines = infp.readlines()
-        self.assertEqual(len(lines), 1)
-        self.assertEqual(lines[0], 'Cate Person <cperson@example.com>\n')
+        self.assertEqual(len(lines), 3)
+        self.assertEqual(lines[0], 'Anne Person <aperson@example.com>\n')
 
     def test_deletion_commented_lines(self):
         subscribe(self._mlist, 'Anne')
@@ -186,7 +186,9 @@ class TestCLIMembers(unittest.TestCase):
                 '--delete', infp.name, 'ant.example.com'))
         self.assertEqual(
             result.output,
-            'Warning: The --delete option is deprecated. Use '
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --delete option is removed. Use '
             '`mailman delmembers` instead.\n')
 
         with NamedTemporaryFile('w', encoding='utf-8') as outfp:
@@ -194,8 +196,8 @@ class TestCLIMembers(unittest.TestCase):
                 '-o', outfp.name, 'ant.example.com'))
             with open(outfp.name, 'r', encoding='utf-8') as infp:
                 lines = infp.readlines()
-        self.assertEqual(len(lines), 1)
-        self.assertEqual(lines[0], 'Bart Person <bperson@example.com>\n')
+        self.assertEqual(len(lines), 2)
+        self.assertEqual(lines[0], 'Anne Person <aperson@example.com>\n')
 
     def test_sync_invalid_email(self):
         with NamedTemporaryFile('w', buffering=1, encoding='utf-8') as infp:
@@ -205,13 +207,10 @@ class TestCLIMembers(unittest.TestCase):
                 '--sync', infp.name, 'ant.example.com'))
         self.assertEqual(
             result.output,
-            'Warning: The --sync option is deprecated. '
-            'Use `mailman syncmembers` instead.\n'
-            'Cannot parse as valid email address'
-            ' (skipping): Dont Subscribe <not-a-valid-email>\n'
-            'Cannot parse as valid email address'
-            ' (skipping): not-a-valid@email\n'
-            'Nothing to do\n')
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --sync option is removed. '
+            'Use `mailman syncmembers` instead.\n')
 
     def test_sync_no_change(self):
         subscribe(self._mlist, 'Anne')
@@ -222,9 +221,10 @@ class TestCLIMembers(unittest.TestCase):
                 '--no-change', '--sync', infp.name, 'ant.example.com'))
         self.assertEqual(
             result.output,
-            'Warning: The --sync option is deprecated. '
-            'Use `mailman syncmembers` instead.\n'
-            '[DEL] Bart Person <bperson@example.com>\n')
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --sync option is removed. '
+            'Use `mailman syncmembers` instead.\n')
 
     def test_sync_empty_tuple(self):
         subscribe(self._mlist, 'Anne')
@@ -236,10 +236,10 @@ class TestCLIMembers(unittest.TestCase):
                 '--no-change', '--sync', infp.name, 'ant.example.com'))
         self.assertEqual(
             result.output,
-            'Warning: The --sync option is deprecated. '
-            'Use `mailman syncmembers` instead.\n'
-            'Cannot parse as valid email address (skipping): ""\n'
-            '[DEL] Bart Person <bperson@example.com>\n')
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --sync option is removed. '
+            'Use `mailman syncmembers` instead.\n')
 
     def test_sync_commented_lines(self):
         subscribe(self._mlist, 'Anne')
@@ -251,16 +251,17 @@ class TestCLIMembers(unittest.TestCase):
                 '--sync', infp.name, 'ant.example.com'))
         self.assertEqual(
             result.output,
-            'Warning: The --sync option is deprecated. '
-            'Use `mailman syncmembers` instead.\n'
-            '[DEL] Bart Person <bperson@example.com>\n')
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --sync option is removed. '
+            'Use `mailman syncmembers` instead.\n')
 
         with NamedTemporaryFile('w', encoding='utf-8') as outfp:
             self._command.invoke(members, (
                 '-o', outfp.name, 'ant.example.com'))
             with open(outfp.name, 'r', encoding='utf-8') as infp:
                 lines = infp.readlines()
-        self.assertEqual(len(lines), 1)
+        self.assertEqual(len(lines), 2)
         self.assertEqual(lines[0], 'Anne Person <aperson@example.com>\n')
 
     def test_sync_blank_lines(self):
@@ -274,16 +275,17 @@ class TestCLIMembers(unittest.TestCase):
                 '--sync', infp.name, 'ant.example.com'))
         self.assertEqual(
             result.output,
-            'Warning: The --sync option is deprecated. '
-            'Use `mailman syncmembers` instead.\n'
-            '[DEL] Bart Person <bperson@example.com>\n')
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --sync option is removed. '
+            'Use `mailman syncmembers` instead.\n')
 
         with NamedTemporaryFile('w', encoding='utf-8') as outfp:
             self._command.invoke(members, (
                 '-o', outfp.name, 'ant.example.com'))
             with open(outfp.name, 'r', encoding='utf-8') as infp:
                 lines = infp.readlines()
-        self.assertEqual(len(lines), 1)
+        self.assertEqual(len(lines), 2)
         self.assertEqual(lines[0], 'Anne Person <aperson@example.com>\n')
 
     def test_sync_nothing_to_do(self):
@@ -296,9 +298,10 @@ class TestCLIMembers(unittest.TestCase):
                 '--sync', infp.name, 'ant.example.com'))
         self.assertEqual(
             result.output,
-            'Warning: The --sync option is deprecated. '
-            'Use `mailman syncmembers` instead.\n'
-            'Nothing to do\n')
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --sync option is removed. '
+            'Use `mailman syncmembers` instead.\n')
 
         with NamedTemporaryFile('w', encoding='utf-8') as outfp:
             self._command.invoke(members, (
@@ -318,10 +321,10 @@ class TestCLIMembers(unittest.TestCase):
                 '--sync', infp.name, 'ant.example.com'))
         self.assertEqual(
             result.output,
-            'Warning: The --sync option is deprecated. '
-            'Use `mailman syncmembers` instead.\n'
-            '[ADD] aperson@example.com\n'
-            '[DEL] Bart Person <bperson@example.com>\n')
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --sync option is removed. '
+            'Use `mailman syncmembers` instead.\n')
 
         with NamedTemporaryFile('w', encoding='utf-8') as outfp:
             self._command.invoke(members, (
@@ -329,7 +332,7 @@ class TestCLIMembers(unittest.TestCase):
             with open(outfp.name, 'r', encoding='utf-8') as infp:
                 lines = infp.readlines()
         self.assertEqual(len(lines), 1)
-        self.assertEqual(lines[0], 'aperson@example.com\n')
+        self.assertEqual(lines[0], 'Bart Person <bperson@example.com>\n')
 
     def test_sync_del_no_display_name(self):
         with NamedTemporaryFile('w', buffering=1, encoding='utf-8') as infp:
@@ -343,10 +346,10 @@ class TestCLIMembers(unittest.TestCase):
                 '--sync', infp.name, 'ant.example.com'))
         self.assertEqual(
             result.output,
-            'Warning: The --sync option is deprecated. '
-            'Use `mailman syncmembers` instead.\n'
-            '[ADD] aperson@example.com\n'
-            '[DEL] bperson@example.com\n')
+            'Usage: members [OPTIONS] LISTSPEC\n'
+            'Try \'members --help\' for help.\n\n'
+            'Error: The --sync option is removed. '
+            'Use `mailman syncmembers` instead.\n')
 
         with NamedTemporaryFile('w', encoding='utf-8') as outfp:
             self._command.invoke(members, (
@@ -354,7 +357,7 @@ class TestCLIMembers(unittest.TestCase):
             with open(outfp.name, 'r', encoding='utf-8') as infp:
                 lines = infp.readlines()
         self.assertEqual(len(lines), 1)
-        self.assertEqual(lines[0], 'aperson@example.com\n')
+        self.assertEqual(lines[0], 'ant.example.com has no members\n')
 
     def test_email_only(self):
         subscribe(self._mlist, 'Anne')
