@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2020 by the Free Software Foundation, Inc.
+# Copyright (C) 2007-2021 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -146,7 +146,7 @@ class Member(Model):
         """See `IMember`."""
         return (self._user
                 if self._address is None
-                else getUtility(IUserManager).get_user(self._address.email))
+                else self._address.user)
 
     @property
     def subscriber(self):
